##  In This Section
  * [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.")
  * [Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD "Calculations let you populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic.")
  * [Export](https://help.sap.com/docs/leanix/ea/export?locale=en-US&state=PRODUCTION&version=CLOUD "Export your workspace data and view the export history.")
  * [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Configure KPIs and display them on dashboards to track enterprise architecture metrics.")
  * [Metrics](https://help.sap.com/docs/leanix/ea/metrics?locale=en-US&state=PRODUCTION&version=CLOUD "Metrics help you to display KPIs and their development over time in the context of the right Fact Sheet.")
  * [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace.")
  * [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
  * [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Download custom reports from the SAP LeanIX Store and make them available to all workspace users.")
  * [To-Dos (Administration)](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD "As an admin, learn how to create approval to-dos and manage all the to-do items in the administration area.")
  * [Workspace Views Configuration](https://help.sap.com/docs/leanix/ea/workspace-views-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Workspace views help users limit the scope of displayed information and focus on their current tasks. Configure custom workspace views tailored to typical use cases and scenarios, specifying which dashboards, fact sheets, reports, and diagrams to include.")


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
